@@ -1,12 +1,14 @@
 #![feature(test)]
 
 extern crate test;
-use safecoin_sdk::{
-    account::{create_account_for_test, from_account},
-    hash::Hash,
-    slot_hashes::{Slot, SlotHashes, MAX_ENTRIES},
+use {
+    safecoin_sdk::{
+        account::{create_account_for_test, from_account},
+        hash::Hash,
+        slot_hashes::{Slot, SlotHashes, MAX_ENTRIES},
+    },
+    test::Bencher,
 };
-use test::Bencher;
 
 #[bench]
 fn bench_to_from_account(b: &mut Bencher) {
